;===============================================================================
;
; Description:      Functions for working with SysIPAddress32 control
; Requirement(s):   Autoit BETA with DllStruct
; Author(s):        YDY (Lazycat)
; Version:          1.01
; Date:             11.05.2006
;
;===============================================================================

#include-once
;===============================================================================
;
; Description:      Set valid range to given field
; Parameter(s):     Control handle, field index (1...4), lower bound, upper bound
; Return Value(s):  1 if successfull, zero otherwise
;
;===============================================================================
Func _GUICtrlSysIPSetRange($hControl, $nField, $nLower, $nUpper)
    Local $IPM_SETRANGE = 0x400 + 103
    Local $nRange = $nLower + BitShift($nUpper, -8)
    Local $ret = DllCall("user32.dll", "ptr", "SendMessage", "hwnd", $hControl, _
                                                "int", $IPM_SETRANGE, _
                                                "int", $nField - 1, _
                                                "int", $nRange)
    If @error or not $ret[0] Then Return 0
    Return 1
EndFunc

;===============================================================================
;
; Description:      Set focus to given field
; Parameter(s):     Control handle, field index (1...4)
;
;===============================================================================
Func _GUICtrlSysIPSetFocus($hControl, $nField = 1)
    Local $IPM_SETFOCUS = 0x400 + 104
    DllCall("user32.dll", "ptr", "SendMessage", "hwnd", $hControl, _
                                                "int", $IPM_SETFOCUS, _
                                                "int", $nField - 1, _
                                                "int", 0)
EndFunc

;===============================================================================
;
; Description:      Clear control
; Parameter(s):     Control handle
;
;===============================================================================
Func _GUICtrlSysIPClear($hControl)
    Local $IPM_CLEARADDRESS = 0x400 + 100
    DllCall("user32.dll", "ptr", "SendMessage", "hwnd", $hControl, _
                                                "int", $IPM_CLEARADDRESS, _
                                                "int", 0, _
                                                "int", 0)
EndFunc

;===============================================================================
;
; Description:      Set data to control
; Parameter(s):     Control handle, string like 127.0.0.1
; Return Value(s):  1 if successfull, zero otherwise
;
;===============================================================================
Func _GUICtrlSysIPSetData($hControl, $sData)
    Local $nIP = 0, $IPM_SETADDRESS = 0x400 + 101
    $sData = StringSplit($sData, ".")
    If UBound($sData) <> 5 Then Return 0
    For $i = 0 To 3
        $nIP = $nIP + BitShift($sData[4 - $i], -(8 * $i))
    Next
    DllCall("user32.dll", "ptr", "SendMessage", "hwnd", $hControl, _
                                                "int", $IPM_SETADDRESS, _
                                                "int", 0, _
                                                "ptr", $nIP)
    If @error Then Return 0
    Return 1
EndFunc

;===============================================================================
;
; Description:      Read data from SysIPAddress32 control
; Parameter(s):     Control handle
; Return Value(s):  If successfull - string with IP, empty string otherwise
; Error(s) set:     If DllStruct or DllCall fail
;
;===============================================================================

Func _GUICtrlSysIPGetData($hControl)
    Local $IPM_GETADDRESS = 0x400 + 102
    $dwIP = DllStructCreate("ubyte;ubyte;ubyte;ubyte")
    If @error Then
        SetError(1)
        Return("")
    Endif
    DllCall("user32.dll", "ptr", "SendMessage", "hwnd", $hControl, _
                                                "int", $IPM_GETADDRESS, _
                                                "int", 0, _
                                                "ptr", DllStructGetPtr($dwIP))
    If @error Then
        SetError(2)
        Return("")
    Endif
    $ret = StringFormat("%d.%d.%d.%d", DllStructGetData($dwIP, 4), _
                                       DllStructGetData($dwIP, 3), _
                                       DllStructGetData($dwIP, 2), _
                                       DllStructGetData($dwIP, 1))
    $dwIP = 0
    Return $ret
EndFunc

;===============================================================================
;
; Description:      Create SysIPAddress32 control
; Parameter(s):     Parent GUI handle, left and top coordinates, width, height, Style and exStyle 
; Return Value(s):  If successfull - control handle, zero otherwise
; Error(s) set:     If DllCall fail
;
;===============================================================================

Func _GUICtrlCreateSysIP($hGUI, $nLeft, $nTop, $nWidth = 120, $nHeight = 20, $nStyle = 0x50000000, $nExStyle = 0)
    Local $GWL_HINSTANCE = -6, $WM_SETFONT = 0x30, $DEFAULT_GUI_FONT = 0x11
    If $nStyle = -1 Then $nStyle = 0x50000000
    Local $hInst = DLLCall("user32.dll","long","GetWindowLong","hwnd", $hGUI, "int", $GWL_HINSTANCE)
    Local $ret = DllCall("user32.dll", "hwnd", "CreateWindowEx", _
                                       "long", $nExStyle, _
                                       "str", "SysIPAddress32", _
                                       "str", "", _
                                       "long", $nStyle, _
                                       "int", $nLeft, _
                                       "int", $nTop, _
                                       "int", $nWidth, _ 
                                       "int", $nHeight, _
                                       "hwnd", $hGUI, _
                                       "hwnd", 0, _
                                       "int", $hInst[0], _
                                       "ptr", "")
    Local $hControl = $ret[0]
    If @error Then
        SetError(1)
        Return(0)
    Endif

    $ret = DllCall("gdi32", "long", "GetStockObject", "long", $DEFAULT_GUI_FONT)
    DllCall("user32.dll", "int", "SendMessage", "hwnd", $hControl, _
                                                "int",  $WM_SETFONT, _
                                                "int",  $ret[0], _
                                                "ptr",  0)
    Return $hControl
Endfunc
